# --- File  : ag_dataviewer.tcl
# --- Date  : 29-Nov-2005
# --- By    : Harald Sund
# --- About : Quick and dirty data displayer

if [file exists "$ag_tmp::dir/$ag::area_name/etopo2"] {
} else {
  qinformation "Warning" "You cannot use this functionality before a project exists."
  return
}

cd "$ag_tmp::dir"
cd $ag::area_name

# her m inn en sjekk p om hi etopo2 eksisterer....

############################
proc AG_Display_track {tema type} {
  rea geodas/$tema/00_all.vtk
  zap etopo2
  sub $ag_tmp::sub
  sub $ag_tmp::sub
  sub $ag_tmp::sub
  if {$type == "track"} {add $ag_tmp::sub}
  col $ag::pen_color
  pol $ag::pen_width
}

###################################
proc AG_Seabed_display {etopo2} {
  rea $etopo2
  ssc
  mhi etopo2

  if {$ag::etopo2_display_reduced == 0} {clip z 0 nrg}
  if {$ag::etopo2_display_reduced == 1} {clip z 0}
  ctable set Sea
  if {$ag::etopo2_display_smooth == 0} {map}
  if {$ag::etopo2_display_smooth == 1} {map nor}
  ctable set Default
}

###################################
proc AG_Land_display {etopo2} {
  rea $etopo2
  ssc
  mhi etopo2

  if {$ag::etopo2_display_reduced == 0} {clip z 0 nrg rev}
  if {$ag::etopo2_display_reduced == 1} {clip z 0 rev}
  ctable set Land
  if {$ag::etopo2_reduce_land_height == 1} {div 4}
  if {$ag::etopo2_display_smooth == 0} {map}
  if {$ag::etopo2_display_smooth == 1} {map nor}
  ctable set Default
}

# sjekk om variable eksisterer
if {[info exists ag_tmp::panel_dataviewer]} {
  # sjekk om panelet eksisterer
  if [qexists $ag_tmp::panel_dataviewer] {
    qinformation "Warning" "You cannot start multiple sessions of this panel. <BR>The panel is present somewhere"
    return
  }
}

# ----------------------#
# ---- Start panel ---- #
# ----------------------#

set ag_tmp::panel_dataviewer [qwidget $ag_tmp::main_panel window] 
qsetattribute deleteonclose
qsetwindowtitle "Quick data viewer"

qgridlayout {
  qsetspacing 0

  qpushbutton "Etopo2 Seabed" {
    AG_Seabed_display etopo2/etopo2.vtk
  }
  qpushbutton "Etopo2 Seabed 5min" {
    AG_Seabed_display etopo2/etopo2_05min.vtk
  }
  qpushbutton "Etopo2 Seabed 10min" {
    AG_Seabed_display etopo2/etopo2_10min.vtk
  }


  qnewgridline

  qpushbutton "Land" {
    AG_Land_display etopo2/etopo2.vtk
  }
  qpushbutton "Land 5min" {
    AG_Land_display etopo2/etopo2_05min.vtk
  }
  qpushbutton "Land 10min" {
    AG_Land_display etopo2/etopo2_10min.vtk
  }

  qnewgridline

  qpushbutton "2500m Isobath" {
    rea 2500m_contour/2500m.vtk
    sub $ag_tmp::sub
    col 0 0 .8
    pol 4
    add $ag_tmp::sub
  }

  if {$ag::projection != "Geographic"} {
    qpushbutton "200M line" {
      rea limitline/200M_FlatEarth_CoarseCoast.vtk
      zap etopo2
      sub $ag_tmp::sub
      col pin
      pol 4 
      add $ag_tmp::sub
    }
  
    qpushbutton "350M line" {
      rea limitline/350M_FlatEarth_CoarseCoast.vtk
      zap etopo2
      sub $ag_tmp::sub
      col 1 .5 0
      pol 4 
      add $ag_tmp::sub
    }
  }
  qnewgridline

  qpushbutton "State borders" {
    rea states/state_borders.vtk
    if {[gvar numpoint] > 2} {
      zap etopo2
      if {$ag::etopo2_reduce_land_height == 1} {div 4}
      sub $ag_tmp::sub
      if {$ag::etopo2_skip_land_display == 1} {mul 0}
      col yel
      pol 4
    }
  }

  qpushbutton "Coast lines" {
    rea coastline/coastline.vtk 
    zap etopo2
    sub $ag_tmp::sub
    col 1 .7 0
    pol
    add $ag_tmp::sub
  }

  qpushbutton "Wells" {
    rea wells/odp.vtk
    zap etopo2
    sub $ag_tmp::sub
    spe mar sphere
    col red
    poi 0.4
    spe mar cube
    add $ag_tmp::sub
  }

  qnewgridline

  qlabel "<B> TRACK LINES </B>   Color:"

  qcombobox
  qadditems {"red" "gre" "blu" "pin" "tur" "yel" "whi" "bla" "bro"}
  qblockedtrace ag::pen_color

  qlabel " Line width : "
  qcombobox
  qadditems {1 2 3 4 5 6 7 8 9}
  qblockedtrace ag::pen_width

  qnewgridline

  qpushbutton "Track lines" {
    AG_Display_track Track_Line track
  }
  qpushbutton "Bathymetry_2_Way_Traveltime" {
    AG_Display_track Bathymetry_2_Way_Traveltime red
  }
  qpushbutton "Bathymetry_Corrected_Depth" {
    AG_Display_track Bathymetry_Corrected_Depth red
  }

  qnewgridline

  qpushbutton "CDP_Sesmic_Reflection" {
    AG_Display_track CDP_Sesmic_Reflection red
  }
  qpushbutton "Digital_Shot_Point_Navigation" {
    AG_Display_track Digital_Shot_Point_Navigation red
  }
  qpushbutton "Free_Air_Anomaly" {
    AG_Display_track Free_Air_Anomaly red
  }

  qnewgridline

  qpushbutton "Magnetics_Residual_Field" {
    AG_Display_track Magnetics_Residual_Field red
  }
  qpushbutton "Magnetics_Total_Field_1st_Sensor" {
    AG_Display_track Magnetics_Total_Field_1st_Sensor red
  }
  qpushbutton "Magnetics_Total_Field_2nd_Sensor" {
    AG_Display_track Magnetics_Total_Field_2nd_Sensor red
  }

  qnewgridline

  qpushbutton "Multibeam_Bathymetry" {
    AG_Display_track Multibeam_Bathymetry red
  }
  qpushbutton "Observed_Gravity" {
    AG_Display_track Observed_Gravity red
  }
  qpushbutton "Seismic_Refraction" {
    AG_Display_track Seismic_Refraction red
  }

  qnewgridline

  qpushbutton "Side_Scan_Sonar" {
    AG_Display_track Side_Scan_Sonar red
  }
  qpushbutton "Single_Channel_Sesmic_Reflection" {
    AG_Display_track Single_Channel_Sesmic_Reflection red
  }

  qsetmargin 5
}
qshow $ag_tmp::panel_dataviewer

# --- eof
