# --- File  : ag_db_creator.tcl
# --- Date  : 22-Oct-2007
# --- By    : Harald Sund
# --- About : Areagenerator DB

set button [qinformation "DB Preview" "<P>Test on db:" "Continue" "Cancel"]
if {$button == 1} {
  return
} else {
  puts "Testing DB"
}

# Connecting to an ODBC server
#
qadddatabase QODBC ag_db

# Create an ODBC connection string for connecting 
# to an instance of Microsoft SQL Server on the host POWER
set odbc_string "DRIVER={SQL Server};SERVER=ANDEBY_M90\\SQLEXPRESS"
qsetdatabasename ag_db $odbc_string
qopendatabase ag_db

#qexecquery ag_db "DROP DATABASE Area_Generator"
qexecquery ag_db "CREATE DATABASE Area_Generator"

# --- Create tables
qexecquery ag_db "USE Area_Generator" ; # DONT USE MASTER!!!!!!!!
qexecquery ag_db "CREATE TABLE Data_Source         (id INT IDENTITY PRIMARY KEY NOT NULL, ds_name NVARCHAR(64))"
qexecquery ag_db "CREATE TABLE Data_Type           (id INT IDENTITY PRIMARY KEY NOT NULL, dt_name NVARCHAR(64))"
qexecquery ag_db "CREATE TABLE VTK_Dataobject_Type (id INT PRIMARY KEY NOT NULL, object_type NVARCHAR(64))"
qexecquery ag_db "CREATE TABLE VTK_Datatypes       (id INT PRIMARY KEY NOT NULL, vtk_datatypes NVARCHAR(64))"
qexecquery ag_db "CREATE TABLE Countries           (id INT IDENTITY PRIMARY KEY NOT NULL,country_name NVARCHAR(64),filename NVARCHAR(256),xmin FLOAT,xmax FLOAT,ymin FLOAT,ymax FLOAT,noof_points INT,noof_cells INT)"

# --- populate table Data_Type
qexecquery ag_db "INSERT INTO Data_Type VALUES ('Multibeam')"
qexecquery ag_db "INSERT INTO Data_Type VALUES ('Bathymetry')"
qexecquery ag_db "INSERT INTO Data_Type VALUES ('Global Grid')"
qexecquery ag_db "INSERT INTO Data_Type VALUES ('Coast Line')"
qexecquery ag_db "INSERT INTO Data_Type VALUES ('Track Line')"
qexecquery ag_db "INSERT INTO Data_Type VALUES ('ECS Line')"

# --- populate table VTK_Dataobject_Type
qexecquery ag_db "INSERT INTO VTK_Dataobject_Type VALUES ('0', 'vtk_poly_data')"
qexecquery ag_db "INSERT INTO VTK_Dataobject_Type VALUES ('1', 'vtk_structured_points')"

# --- populate table VTK_Datatype
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('0',  'vtk_void')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('1',  'vtk_bit')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('2',  'vtk_char')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('15', 'vtk_signed_char')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('3',  'vtk_unsigned_char')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('4',  'vtk_short')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('5',  'vtk_unsigned_short')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('6',  'vtk_int')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('7',  'vtk_unsigned_int')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('8',  'vtk_long')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('9',  'vtk_unsigned_long')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('10', 'vtk_float')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('11', 'vtk_double')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('12', 'vtk_id_type')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('13', 'vtk_string')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('14', 'vtk_opaque')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('16', 'vtk_long_long')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('17', 'vtk_unsigned_long_long')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('18', 'vtk___int64')"
qexecquery ag_db "INSERT INTO VTK_Datatypes VALUES ('19', 'vtk_unsigned___int64')"

# --- populate table Data_Source
set dirlist [glob -nocomplain $ag_tmp::master_data_path/*]
foreach dir $dirlist {
  set datasource [file rootname [file tail $dir]]
  qexecquery ag_db "INSERT INTO Data_Source VALUES ('$datasource')"
}


# ------------
set filelist [glob -nocomplain $ag_tmp::master_data_path/Coastline/wvsplus/wvsplus_VTK/*.vtk]
puts "Build country table"


# Create a query object
set query_object [qsqlquery ag_db]

foreach vtk $filelist {
  set filename $vtk
  rea $vtk
  set tailname [file tail $vtk]
  set countryname [file rootname [file tail $vtk]]
  set xmin [gvar xmin]
  set xmax [gvar xmax]
  set ymin [gvar ymin]
  set ymax [gvar ymax]
  set noof_points [gvar numpoint]
  set noof_cells  [gvar numcell]
  #qexecquery ag_db "INSERT INTO Countries VALUES ('$countryname', '$filename')"

  # Prepare a statement using placeholders for id, name, an age.
  qprepare $query_object "INSERT INTO Countries VALUES (:countryname, :filename, :xmin, :xmax, :ymin, :ymax, :noof_points, :noof_cells)"

  qbindvalue $query_object :countryname $countryname 
  qbindvalue $query_object :filename $filename
  qbindvalue $query_object :xmin $xmin
  qbindvalue $query_object :xmax $xmax
  qbindvalue $query_object :ymin $ymin
  qbindvalue $query_object :ymax $ymax
  qbindvalue $query_object :noof_points $noof_points
  qbindvalue $query_object :noof_cells $noof_cells

  # Execute prepared query
  qexecquery $query_object
}

qclosedatabase ag_db
qremovedatabase ag_db ;# fjerner connection

puts "DB Completed"



# --- eof
