# --- File  : ag_preview_geo.tcl
# --- Date  : 26-Jun-2007
# --- By    : Harald Sund
# --- About : Preview geographic area, Coastline and state borders

set ag_tmp::passes_dateline 0

if {$ag::ygeomax <= $ag::ygeomin} {
  if {$ag::ygeomin != ""} {
    qinformation "Area Generator Error Message" "You have not entered correct North-South coordinates.
    North coordinate is less than (or equal to) South coordinate"
    return
  }
}

zz
d2

# --- Set window, draw axes and background
win -180 180 -90 90 0 0.3
axe 1.0 inx 30 iny 20 tic
col whi
dra dwa
col .3 .3 .5
#pla z 0.1
#acp * opa .2

edi cur -180 90 0
axe 1.0 cur inx 30 iny 20 tic

scaz 1

# --- X-Linjer
set i -170
while {$i < 171} {
  col .6 .7 .5
  lin x $i
  set i [expr $i + 10]
}

spe liw 2
set i -150
while {$i < 151} {
  col .7 .7 .7
  lin x $i
  set i [expr $i + 30]
}
spe liw off

# --- Y-linjer
set i -80
while {$i < 81} {
  col .6 .7 .5
  lin y $i
  set i [expr $i + 10]
}

spe liw 2
set i -80
while {$i < 81} {
  col .7 .7 .7
  lin y $i
  set i [expr $i + 20]
}

# --- White Origin lines
col whi
lin x 0
col whi
lin y 0
spe liw off


# --- Display coastlines
set file $ag_tmp::master_data_path/UN_Boundaries_01/UN_Coastline_01M.vtk
set file2 $ag_tmp::master_data_path/Coastline/wvsplus/wvsplus.vtk
set file3 $ag_tmp::master_data_path/Coastline/gshhs/gshhs_i.b
if [file exists $file] {
  rea $file
  col 0 .8 0
  pol
} elseif [file exists $file2] {
  rea auto xmin -180 xmax 180 ymin -90 ymax 90 $file2
  col 0 .8 0
  pol
} elseif [file exists $file3] {
  rea auto xmin -180 xmax 180 ymin -90 ymax 90 $file3
  col 0 .8 0
  pol
}

set f $ag_tmp::master_data_path//Norway/Norway_UTM33_Seabed_Inbox/Seabed_DEMs_Geodetic.vtk
if [file exists $f] {
  rea $f
  col .3 .3 .3
  pol
}

# --- Display State borders
set file $ag_tmp::master_data_path/UN_Boundaries_01/UN_IntBoundaries_01M.vtk
if [file exists $file] {
  rea $file
  col .8 .8 0
  pol
}

# --- Display Seabed
# dette eksisterer ikke....
#set file $ag_tmp::master_data_path/Global_Grids/ETOPO2v2_10min.vtk
#mhi sticky_surface

set do_it 1

set xmin [expr $ag::xgeomin - 10]
set xmax [expr $ag::xgeomax + 10]
set ymin [expr $ag::ygeomin - 10]
set ymax [expr $ag::ygeomax + 10]

if {$do_it == 1} {

  # Her m jeg sjekke om x-coord strekker seg over 180
  if {$ag::xgeomin > $ag::xgeomax} {
    AG_Read_grid ETOPO2v2.vtk $xmin 180 $ymin $ymax
    ctable set "Sea"
    eli lt 0
    div 1000
    map nor

    AG_Read_grid ETOPO2v2.vtk -180 $xmax $ymin $ymax
    ctable set "Sea"
    eli lt 0
    div 1000
    map nor

    #tra 180 0 0

  } else {
    AG_Read_grid ETOPO2v2.vtk $xmin $xmax $ymin $ymax
    ctable set "Sea"
    eli lt 0
    div 1000
    map nor
  }
  ctable set "Default"
}


# --- Display GMDB
#set file $ag_tmp::master_data_path/GMBD/GMBD_Detailed_Lines_VTK/Undisputed_Unilateral_Claim/Economic_zone+High_Seas.vtk
set file $ag_tmp::master_data_path/GMBD/GMBD_Lines_VTK/highseas.vtk
if [file exists $file] {
  rea $file
  #zap sticky_surface
  col pin
  pol
  ssc
}

if {$ag::xgeomin == ""} {return}
if {$ag::xgeomax == ""} {return}
if {$ag::ygeomin == ""} {return}
if {$ag::ygeomax == ""} {return}

sta $ag::xgeomin $ag::ygeomin 0
sta $ag::xgeomin $ag::ygeomax 0
sta $ag::xgeomax $ag::ygeomax 0
sta $ag::xgeomax $ag::ygeomin 0
sta $ag::xgeomin $ag::ygeomin 0
rea ter

if {$ag::xgeomax <= $ag::xgeomin} {
  sta -180 $ag::ygeomin 0
  sta $ag::xgeomax $ag::ygeomin 0
  sta $ag::xgeomax $ag::ygeomax 0
  sta -180 $ag::ygeomax 0
  sta 999 999 999
  sta 180 $ag::ygeomin 0
  sta $ag::xgeomin $ag::ygeomin 0
  sta $ag::xgeomin $ag::ygeomax 0
  sta 180 $ag::ygeomax 0
  rea ter
}

sub .2
col 1 0 0
pol 3
mak sha
col whi
#dis
#acp * opa .3
d3
asc
d2

#######################################
proc AG_Rubberband_select {x1 y1 x2 y2} {
  set x1 [format "%5.3f" $x1]
  set x2 [format "%5.3f" $x2]
  set y1 [format "%5.3f" $y1]
  set y2 [format "%5.3f" $y2]

  set ag::xgeomin $x1
  set ag::xgeomax $x2
  set ag::ygeomin $y1
  set ag::ygeomax $y2

  sta $x1 $y1 0 
  sta $x2 $y1 0
  sta $x2 $y2 0
  sta $x1 $y2 0
  sta $x1 $y1 0
  rea ter
  pol 2
}



# ----------------------#
# ---- Start panel ---- #
# ----------------------#

set ag_tmp::panel_agrectangle [qwidget $ag_tmp::main_panel window]
qsetattribute deleteonclose
qsetwindowtitle "Select new area"
qvboxlayout {
  qsetspacing 0

  qgroupbox "Select new area"
  qgridlayout {

    qlabel
    qnewgridline

    qpushbutton "Select by drawing a rectangle" "  rubberband select AG_Rubberband_select"
    qsettooltip "<p>Select coordinates by drawing a rectangle on screen, <b>Esc</b> to escape."
    qseticon [qicon "$ag_tmp::path/icons/rubberband_select.png"] 
    if {[geocapversion major] < 6} {
      qsetenabled 0
      qnewgridline
      qlabel
      qnewgridline
      qlabel "The select functionality is only available in Geocap 6.3 and newer versions"
      qnewgridline
      qlabel
    } elseif {[geocapversion major] == 6} {
      if {[geocapversion minor] < 3} {
      qsetenabled 0
      qnewgridline
      qlabel
      qnewgridline
      qlabel "The select functionality is only available in Geocap 6.3 and newer versions"
      qnewgridline
      qlabel
      }
    }

    qnewgridline
    qlabel

    qsetmargin 5
  }

  qpushbutton "Close" {
    qclose $ag_tmp::panel_agrectangle 
  }
  qsetalignment alignright
}

qshow $ag_tmp::panel_agrectangle


# --- eof
